==> com.liferay.dispatch.web-3.0.1-sources.jar: com/liferay/dispatch/web/internal/portlet/action/EditDispatchLogMVCActionCommand.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.dispatch.web.internal.portlet.action;

import com.liferay.dispatch.constants.DispatchPortletKeys;
import com.liferay.dispatch.service.DispatchLogService;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.portlet.bridges.mvc.BaseMVCActionCommand;
import com.liferay.portal.kernel.portlet.bridges.mvc.MVCActionCommand;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.util.Constants;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.StringUtil;

import java.util.Objects;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author guywandji
 * @author Alessio Antonio Rendina
 */
@Component(
	property = {
		"javax.portlet.name=" + DispatchPortletKeys.DISPATCH,
		"mvc.command.name=/dispatch/edit_dispatch_log"
	},
	service = MVCActionCommand.class
)
public class EditDispatchLogMVCActionCommand extends BaseMVCActionCommand {

	protected void deleteDispatchLog(ActionRequest actionRequest)
		throws PortalException {

		long[] deleteDispatchLogIds = null;

		long dispatchLogId = ParamUtil.getLong(actionRequest, "dispatchLogId");

		if (dispatchLogId > 0) {
			deleteDispatchLogIds = new long[] {dispatchLogId};
		}
		else {
			deleteDispatchLogIds = StringUtil.split(
				ParamUtil.getString(actionRequest, "deleteDispatchLogIds"), 0L);
		}

		for (long deleteDispatchLogId : deleteDispatchLogIds) {
			_dispatchLogService.deleteDispatchLog(deleteDispatchLogId);
		}
	}

	@Override
	protected void doProcessAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws Exception {

		String cmd = ParamUtil.getString(actionRequest, Constants.CMD);

		try {
			if (Objects.equals(cmd, Constants.DELETE)) {
				deleteDispatchLog(actionRequest);
			}
		}
		catch (Exception exception) {
			SessionErrors.add(actionRequest, exception.getClass());

			actionResponse.setRenderParameter("mvcPath", "/error.jsp");
		}
	}

	@Reference
	private DispatchLogService _dispatchLogService;

}

==> com.liferay.dispatch.web-3.0.49-sources.jar: com/liferay/dispatch/web/internal/portlet/action/EditDispatchLogMVCActionCommand.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.dispatch.web.internal.portlet.action;

import com.liferay.dispatch.constants.DispatchPortletKeys;
import com.liferay.dispatch.service.DispatchLogService;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.portlet.bridges.mvc.BaseMVCActionCommand;
import com.liferay.portal.kernel.portlet.bridges.mvc.MVCActionCommand;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.util.Constants;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.StringUtil;

import java.util.Objects;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author guywandji
 * @author Alessio Antonio Rendina
 */
@Component(
	property = {
		"javax.portlet.name=" + DispatchPortletKeys.DISPATCH,
		"mvc.command.name=/dispatch/edit_dispatch_log"
	},
	service = MVCActionCommand.class
)
public class EditDispatchLogMVCActionCommand extends BaseMVCActionCommand {

	@Override
	protected void doProcessAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws Exception {

		String cmd = ParamUtil.getString(actionRequest, Constants.CMD);

		try {
			if (Objects.equals(cmd, Constants.DELETE)) {
				_deleteDispatchLog(actionRequest);
			}
		}
		catch (Exception exception) {
			SessionErrors.add(actionRequest, exception.getClass());

			actionResponse.setRenderParameter("mvcPath", "/error.jsp");
		}
	}

	private void _deleteDispatchLog(ActionRequest actionRequest)
		throws PortalException {

		long[] deleteDispatchLogIds = null;

		long dispatchLogId = ParamUtil.getLong(actionRequest, "dispatchLogId");

		if (dispatchLogId > 0) {
			deleteDispatchLogIds = new long[] {dispatchLogId};
		}
		else {
			deleteDispatchLogIds = StringUtil.split(
				ParamUtil.getString(actionRequest, "deleteDispatchLogIds"), 0L);
		}

		for (long deleteDispatchLogId : deleteDispatchLogIds) {
			_dispatchLogService.deleteDispatchLog(deleteDispatchLogId);
		}
	}

	@Reference
	private DispatchLogService _dispatchLogService;

}
